==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/co/gco102.h <==
/*!================================================================
 module:        hco18.h
 
 responsible:   ThomasA
 
 special area:  OMS
 
 description:   Oms Tracing   
 
 see:
 
 copyright:     SAP AG 1998 


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

 ===================================================================*/

#ifndef GCO102_H
#define GCO102_H

#include <string.h>
#include <stdio.h>
#include "gsp00.h"
#include "hco31-k.h" 

enum ETraceLevel_co102 {
  omsTrAlways = 1,
  omsTrError = 2,
  omsTrInterface = 4,
  omsTrContainerDir = 8,
  omsTrMemory = 16,
  omsTrVarObject = 32,
  omsTrTrans = 64,
  omsTrSession = 128,
  omsEnumLimit = 1024
};

class CTraceLevel_co102 {
public :
  CTraceLevel_co102() : m_traceLevel(1) {
  }
  bool operator[](tsp00_Uint4 lvl) {
    return ((m_traceLevel & lvl) > 0);
  }
   void disable(ETraceLevel_co102 lvl) {
     m_traceLevel &= ((tsp00_Uint4) lvl ^ 0xFFFFFFFF);
  }
  void enable(ETraceLevel_co102 lvl) {
     m_traceLevel |= (tsp00_Uint4) lvl;
  }
  void enableAll() {
    m_traceLevel = 0xFFFFFFFF;
  }
  bool Set (tsp00_KnlIdentifier& lvl, bool enable);
private :
   tsp00_Uint4 m_traceLevel;
};


#if !defined(EXTERN_CO102)
#define EXTERN_CO102 extern
#endif

EXTERN_CO102 CTraceLevel_co102 TraceLevel_co102;

class CUnsignedChar_co102 {
public :
  inline CUnsignedChar_co102(const unsigned char*, int);
  inline unsigned char operator[](int) const;
  inline int length() const;
private :
  const unsigned char* m_buf;
  int                  m_length;
};

inline CUnsignedChar_co102::CUnsignedChar_co102(const unsigned char* c, int length) : m_buf(c), m_length(length) {}

inline unsigned char  CUnsignedChar_co102::operator[](int ix) const {
  return m_buf[ix];
}

inline int CUnsignedChar_co102::length() const {
  return m_length;
}

class CFixedLenChar_co102 {
public :
  inline CFixedLenChar_co102(const char*, int);
  inline CFixedLenChar_co102(const unsigned char*, int);
  inline char operator[](int) const;
  inline const char* str() const;
  inline int length() const;
private :
  const char* m_buf;
  int         m_length;
};

inline CFixedLenChar_co102::CFixedLenChar_co102(const char* c, int length) : m_buf(c), m_length(length) {}

inline CFixedLenChar_co102::CFixedLenChar_co102(const unsigned char* c, int length) : m_buf((char*) c), m_length(length) {}

inline const char* CFixedLenChar_co102::str() const {
  return m_buf;
}

inline char CFixedLenChar_co102::operator[](int ix) const {
  return m_buf[ix];
}

inline int CFixedLenChar_co102::length() const {
  return m_length;
}

class CTraceStream_co102 {
public :
  CTraceStream_co102(char* buffer, int bufSize) : m_buffer(buffer), m_bufSize(bufSize), m_length(0), m_radix(10) {};
  CTraceStream_co102& operator<<(const char*);
  CTraceStream_co102& operator<<(const CUnsignedChar_co102&);
  CTraceStream_co102& operator<<(char);
  CTraceStream_co102& operator<<(int i)   { return putInt(i); };
  CTraceStream_co102& operator<<(short i) { return putInt(i); }
  CTraceStream_co102& operator<<(long i)  { return putInt(i); };
  CTraceStream_co102& operator<<(unsigned int i)   { return putUInt(i); };
  CTraceStream_co102& operator<<(unsigned short i) { return putUInt(i); }
  CTraceStream_co102& operator<<(unsigned long i)  { return putUInt(i); };
  CTraceStream_co102& operator<<(double);
  CTraceStream_co102& operator<<(const void*);
  CTraceStream_co102& operator<<(const OmsObjectId&);
  CTraceStream_co102& operator<<(const GUID&);
  CTraceStream_co102& operator<<(const CFixedLenChar_co102&);
  inline int length() const;
private :
  inline void putChar(char);
  CTraceStream_co102& putInt(tsp00_Longint);
  CTraceStream_co102& putUInt(unsigned long);
  char* m_buffer;
  int   m_bufSize;
  int   m_length;
  int   m_radix;
};

inline int CTraceStream_co102::length() const {
  return m_length;
}

inline void CTraceStream_co102::putChar(char c) {
  if (m_length < m_bufSize) {
    m_buffer[m_length] = c;
    ++m_length;
  }
}


#define OMS_TRACE(LVL,SINK,FMT) \
{\
if (TraceLevel_co102[LVL]) {\
  char buffer[256];\
  CTraceStream_co102 s (buffer, sizeof(buffer));\
  s << FMT;\
  SINK->Vtrace (s.length(), (unsigned char*) &buffer[0]);\
}\
}

#endif

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/co/gco102.h <==
/*!================================================================
 module:        hco18.h
 
 responsible:   ThomasA
 
 special area:  OMS
 
 description:   Oms Tracing   
 
 see:
 
 copyright:     SAP AG 1998 


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

 ===================================================================*/

#ifndef GCO102_H
#define GCO102_H

#include <string.h>
#include <stdio.h>
#include "gsp00.h"
#include "hco31-k.h" 

enum ETraceLevel_co102 {
  omsTrAlways = 1,
  omsTrError = 2,
  omsTrInterface = 4,
  omsTrContainerDir = 8,
  omsTrMemory = 16,
  omsTrVarObject = 32,
  omsTrTrans = 64,
  omsTrSession = 128,
  omsTrLock = 256,
  /* the following are for the detail trace only - in DEBUG mode */
  omsTrContext = 512,
  omsTrNewObj = 1024,
  omsEnumLimit = 2048
};

class CTraceLevel_co102 {
public :
  CTraceLevel_co102() : m_traceLevel(omsTrAlways) {
  }
  bool operator[](tsp00_Uint4 lvl) {
    return ((m_traceLevel & lvl) > 0);
  }
   void disable(ETraceLevel_co102 lvl) {
     m_traceLevel &= ((tsp00_Uint4) lvl ^ 0xFFFFFFFF);
  }
  void enable(ETraceLevel_co102 lvl) {
     m_traceLevel |= (tsp00_Uint4) lvl;
  }
  void enableAll() {
    m_traceLevel = 0xFFFFFFFF;
  }
  bool Set (tsp00_KnlIdentifier& lvl, bool enable);
private :
   tsp00_Uint4 m_traceLevel;
};


#if !defined(EXTERN_CO102)
#define EXTERN_CO102 extern
#endif

EXTERN_CO102 CTraceLevel_co102 TraceLevel_co102;

class CUnsignedChar_co102 {
public :
  inline CUnsignedChar_co102(const unsigned char*, int);
  inline unsigned char operator[](int) const;
  inline int length() const;
private :
  const unsigned char* m_buf;
  int                  m_length;
};

inline CUnsignedChar_co102::CUnsignedChar_co102(const unsigned char* c, int length) : m_buf(c), m_length(length) {}

inline unsigned char  CUnsignedChar_co102::operator[](int ix) const {
  return m_buf[ix];
}

inline int CUnsignedChar_co102::length() const {
  return m_length;
}

class CFixedLenChar_co102 {
public :
  inline CFixedLenChar_co102(const char*, int);
  inline CFixedLenChar_co102(const unsigned char*, int);
  inline char operator[](int) const;
  inline const char* str() const;
  inline int length() const;
private :
  const char* m_buf;
  int         m_length;
};

inline CFixedLenChar_co102::CFixedLenChar_co102(const char* c, int length) : m_buf(c), m_length(length) {}

inline CFixedLenChar_co102::CFixedLenChar_co102(const unsigned char* c, int length) : m_buf((char*) c), m_length(length) {}

inline const char* CFixedLenChar_co102::str() const {
  return m_buf;
}

inline char CFixedLenChar_co102::operator[](int ix) const {
  return m_buf[ix];
}

inline int CFixedLenChar_co102::length() const {
  return m_length;
}

class CTraceStream_co102 {
public :
  CTraceStream_co102(char* buffer, int bufSize) : m_buffer(buffer), m_bufSize(bufSize), m_length(0), m_radix(10) {};
  CTraceStream_co102& operator<<(const char*);
  CTraceStream_co102& operator<<(const CUnsignedChar_co102&);
  CTraceStream_co102& operator<<(char);
  CTraceStream_co102& operator<<(int i)   { return putInt(i); };
  CTraceStream_co102& operator<<(short i) { return putInt(i); }
  CTraceStream_co102& operator<<(long i)  { return putInt(i); };
  CTraceStream_co102& operator<<(unsigned int i)   { return putUInt(i); };
  CTraceStream_co102& operator<<(unsigned short i) { return putUInt(i); }
  CTraceStream_co102& operator<<(unsigned long i)  { return putUInt(i); };
  CTraceStream_co102& operator<<(double);
  CTraceStream_co102& operator<<(const void*);
  CTraceStream_co102& operator<<(const OmsObjectId&);
  CTraceStream_co102& operator<<(const GUID&);
  CTraceStream_co102& operator<<(const CFixedLenChar_co102&);
  inline int length() const;
private :
  inline void putChar(char);
  CTraceStream_co102& putInt(tsp00_Longint);
  CTraceStream_co102& putUInt(unsigned long);
  char* m_buffer;
  int   m_bufSize;
  int   m_length;
  int   m_radix;
};

inline int CTraceStream_co102::length() const {
  return m_length;
}

inline void CTraceStream_co102::putChar(char c) {
  if (m_length < m_bufSize) {
    m_buffer[m_length] = c;
    ++m_length;
  }
}


#define OMS_TRACE(LVL,SINK,FMT) \
{\
if (TraceLevel_co102[LVL]) {\
  char buffer[256];\
  CTraceStream_co102 s (buffer, sizeof(buffer));\
  s << FMT;\
  SINK->Vtrace (s.length(), (unsigned char*) &buffer[0]);\
}\
}

#ifdef OMS_DEBUG
#define OMS_DETAIL_TRACE(LVL,SINK,FMT) \
{\
if (TraceLevel_co102[LVL]) {\
  char buffer[256];\
  CTraceStream_co102 s (buffer, sizeof(buffer));\
  s << FMT;\
  SINK->Vtrace (s.length(), (unsigned char*) &buffer[0]);\
}\
}
#else
#define OMS_DETAIL_TRACE(LVL,SINK,FMT)
#endif

#endif
